@@ -3,7 +3,23 @@
 ==============================
 
 A collection of functions to interface with the F1 web api.
+
+.. autosummary::
+   :nosignatures:
+
+   timing_data
+   timing_app_data
+   car_data
+   position_data
+   track_status_data
+   session_status_data
+   driver_info
+   weather_data
+   fetch_page
+   parse
+
 """
+import datetime
 import json
 import base64
 import zlib
@@ -32,6 +48,7 @@ headers = {
 }
 
 pages = {
+  'session_data': 'SessionData.json',  # track + session status + lap count
   'session_info': 'SessionInfo.json',  # more rnd
   'archive_status': 'ArchiveStatus.json',  # rnd=1880327548
   'heartbeat': 'Heartbeat.jsonStream',  # Probably time synchronization?
@@ -50,7 +67,7 @@ pages = {
   'content_streams': 'ContentStreams.jsonStream',  # Lap by lap feeds
   'timing_data': 'TimingData.jsonStream',  # Gap to car ahead
   'lap_count': 'LapCount.jsonStream',  # Lap counter
-  'championship_predicion': 'ChampionshipPrediction.jsonStream'  # Points
+  'championship_prediction': 'ChampionshipPrediction.jsonStream'  # Points
 }
 """Known API requests"""
 
@@ -95,11 +112,17 @@ class Cache:
         cls._IGNORE_VERSION = ignore_version
         cls._FORCE_RENEW = force_renew
         if use_requests_cache:
-            cls._install_requests_cache(cache_dir)
+            cls._install_requests_cache(cache_dir, force_renew=force_renew)
 
     @staticmethod
-    def _install_requests_cache(cache_dir):
-        requests_cache.install_cache(os.path.join(cache_dir, 'fastf1_http_cache'), allowable_methods=('GET', 'POST'))
+    def _install_requests_cache(cache_dir, *, force_renew=False):
+        requests_cache.install_cache(
+            os.path.join(cache_dir, 'fastf1_http_cache'),
+            allowable_methods=('GET', 'POST'),
+            expire_after=datetime.timedelta(hours=12)
+        )
+        if force_renew:
+            requests_cache.clear()
 
     @classmethod
     def clear_cache(cls, cache_dir, deep=False):
@@ -520,6 +543,10 @@ def _laps_data_driver(driver_raw, empty_vals, drv):
             drv_data[key] = drv_data[key][1:]
         drv_data['NumberOfLaps'] = list(map(lambda n: n-1, drv_data['NumberOfLaps']))  # reduce each lap count by one
 
+    if not drv_data['Time']:
+        # ensure that there is still data left after potentially removing a lap
+        return drv_data
+
     # lap time sync; check which sector time was triggered with the lowest latency
     # Sector3SessionTime == end of lap
     # Sector2SessionTime + Sector3Time == end of lap
@@ -548,8 +575,15 @@ def _laps_data_driver(driver_raw, empty_vals, drv):
 
     # last lap needs to be removed if it does not have a 'Time' and it could not be calculated (likely an inlap)
     if pd.isnull(drv_data['Time'][-1]):
-        for key in drv_data.keys():
-            drv_data[key] = drv_data[key][:-1]
+        if not pd.isnull(drv_data['PitInTime'][-1]):
+            drv_data['Time'][-1] = drv_data['PitInTime'][-1]
+        else:
+            for key in drv_data.keys():
+                drv_data[key] = drv_data[key][:-1]
+
+    if not drv_data['Time']:
+        # ensure that there is still data left after potentially removing a lap
+        return drv_data
 
     # more lap sync, this time check which lap triggered with the lowest latency
     for i in range(len(drv_data['Time'])-1, 0, -1):
@@ -721,7 +755,15 @@ def car_data(path, response=None, livedata=None):
         - Gear (int): [called 'nGear' in the data!]
         - Throttle (int): 0-100%
         - Brake (int): 0-100% (don't trust brake too much)
-        - DRS (int): 0=Off, 8=Active; sometimes other values --> to be researched
+        - DRS (int): 0-14 (Odd DRS is Disabled, Even DRS is Enabled) (More Research Needed)
+            | 0 =  Off
+            | 1 =  Off
+            | 2 =  (?)
+            | 3 =  (?)
+            | 8 =  Detected, Eligible once in Activation Zone (Noted Sometimes)
+            | 10 = On (Unknown Distinction)
+            | 12 = On (Unknown Distinction)
+            | 14 = On (Unknown Distinction)
         - Source (str): Indicates the source of a sample; 'car' for all values here
 
     The data stream has a sample rate of (usually) 240ms. The samples from the data streams for position data and
