@@ -84,6 +84,9 @@ SPRINT_QUALIFYING_LOOKUP = {
     14: {'Practice 1': '2021-09-10', 'Qualifying': '2021-09-10',
          'Practice 2': '2021-09-11', 'Sprint Qualifying': '2021-09-11',
          'Race': '2021-09-12'},
+    19: {'Practice 1': '2021-11-12', 'Qualifying': '2021-11-12',
+         'Practice 2': '2021-11-13', 'Sprint Qualifying': '2021-11-13',
+         'Race': '2021-11-14'}
 }
 
 D_LOOKUP = [[44, 'HAM', 'Mercedes'], [77, 'BOT', 'Mercedes'],
@@ -156,16 +159,20 @@ def get_session(year, gp, event=None):
     weekend = Weekend(year, gp)
     if event == 'R':
         return Session(weekend, 'Race')
-    if event == 'Q':
+    elif event == 'Q':
         return Session(weekend, 'Qualifying')
-    if event == 'SQ':  # TODO: remove; temporary patch to support sprint qualifying
+    elif event == 'SQ':  # TODO: remove; temporary patch to support sprint qualifying
         return Session(weekend, 'Sprint Qualifying')
-    if event == 'FP3':
+    elif event == 'FP3':
         return Session(weekend, 'Practice 3')
-    if event == 'FP2':
+    elif event == 'FP2':
         return Session(weekend, 'Practice 2')
-    if event == 'FP1':
+    elif event == 'FP1':
         return Session(weekend, 'Practice 1')
+    elif event is not None:
+        raise ValueError(f"Invalid name '{event}' given for argument "
+                         f"'event'. Valid options are: "
+                         f"['R', 'Q', 'SQ', 'FP1', 'FP2', 'FP3']")
     return weekend
 
 
@@ -235,7 +242,7 @@ class Telemetry(pd.DataFrame):
             - `nGear` (int): Car gear number
             - `Throttle` (float): 0-100 Throttle pedal pressure
             - `Brake` (float): 0-100 Brake pedal pressure
-            - `DRS` (int): DRS indicator
+            - `DRS` (int): DRS indicator (See :meth:`car_data` for more info)
 
         - **Position data**:
             - `X` (float): X position
@@ -891,6 +898,8 @@ class Telemetry(pd.DataFrame):
         for drv in self.session.drivers:
             # find correct first relevant lap; very important for correct zero point in distance
             drv_laps = self.session.laps[self.session.laps['DriverNumber'] == drv]
+            if drv_laps.empty:  # Only include drivers who participated in this session
+                continue
             drv_laps_before = drv_laps[(drv_laps['LapStartTime'] <= t_start)]
             if not drv_laps_before.empty:
                 lap_n_before = drv_laps_before['LapNumber'].iloc[-1]
@@ -1089,9 +1098,9 @@ class Session:
         """Instance of :class:`Laps` containing all laps from all drivers
         in this session."""
         self.t0_date = None
-        # can only be set when/if telemetry has been downloaded
         """pandas.Datetime: Date timestamp which marks the beginning of the
-        data stream."""
+        data stream. This value needs to be calculated from telemetry data
+        and is therefore only available after telemetry data was loaded."""
         self.session_start_time = None
         """pandas.Timedelta: Session time at which the session was started."""
 
@@ -1106,7 +1115,9 @@ class Session:
         self.weather_data = pd.DataFrame()
         """Dataframe containing weather data for this session as received
         from the api. See :func:`fastf1.api.weather_data` for available data
-        channels. Each data channel is one row of the dataframe."""
+        channels. Each data channel is one row of the dataframe.
+        Weather data is only loaded once :func:`Session.load_laps` has been
+        called."""
 
         self.drivers = list()
         """List of all drivers that took part in this session; contains driver numbers as string. Drivers for which
@@ -1248,6 +1259,7 @@ class Session:
                 break
         self.session_status = pd.DataFrame(session_status)
 
+        df = None
         for i, driver in enumerate(self.drivers):
             d1 = data[data['Driver'] == driver]
             d2 = useful[useful['Driver'] == driver]
@@ -1269,6 +1281,7 @@ class Session:
                         result['TotalLaps'] = d2['TotalLaps'].iloc[0]
                         result['New'] = d2['New'].iloc[0]
                 else:
+                    logging.warning(f"No lap data for driver {driver}")
                     continue  # no data for this driver; skip
 
             else:
@@ -1295,21 +1308,30 @@ class Session:
                 result.loc[sel, 'TotalLaps'] += np.arange(0, sel.sum()) + 1
 
             # check if there is another lap during which the session was aborted
+            # but which is not in the data
             # if yes, add as much data as possible for it
             # set the time of abort as lap end time given that there is no
             # accurate time available
+            # this block of code has no tests; testing would require to mock
+            # the data as the actual data may be updated on the server after
+            # some time and the problem no longer occurs
             if pd.isna(result['PitInTime'].iloc[-1]) and not only_one_lap:
                 if not pd.isna(result['Time'].iloc[-1]):
-                    next_status = self.session_status[
+                    next_statuses = self.session_status[
                         self.session_status['Time'] > result['Time'].iloc[-1]
-                    ].iloc[0]
+                    ]
                 else:
-                    next_status = self.session_status[
+                    next_statuses = self.session_status[
                         self.session_status['Time']
                         > result['LapStartTime'].iloc[-1]
-                    ].iloc[0]
+                    ]
 
-                if next_status['Status'] == 'Aborted':
+                aborted = False
+                if not next_statuses.empty:
+                    next_status = next_statuses.iloc[0]
+                    aborted = (next_status['Status'] == 'Aborted')
+
+                if aborted:
                     new_last = pd.DataFrame({
                         'LapStartTime': [result['Time'].iloc[-1]],
                         'Time': [next_status['Time']],
@@ -1326,8 +1348,10 @@ class Session:
                     else:
                         result = new_last
 
-            # check if df is defined already before concat (vars is a builtin function)
-            df = result if 'df' not in vars() else pd.concat([df, result], sort=False)  # noqa: F821
+            df = pd.concat([df, result], sort=False)
+
+        if df is None:
+            raise NoLapDataError
 
         laps = df.reset_index(drop=True)  # noqa: F821
         laps.rename(columns={'TotalLaps': 'TyreLife',
